@@ -1,300 +1,335 @@
-# from __future__ import absolute_import
+from enum import Enum
 
 import jpype
 from asposepdf import Assist
 from jpype import java
-
 from strenum import StrEnum
-from enum import Enum
 
 
 class License(Assist.BaseJavaClass):
     javaClassName = "com.aspose.python.pdf.License"
 
     def __init__(self):
-        javaLicense = jpype.JClass(self.javaClassName)
-        self.javaClass = javaLicense()
-        super().__init__(self.javaClass)
+        java_license = jpype.JClass(self.javaClassName)
+        java_object = java_license()
+        super().__init__(java_object)
 
     def setLicense(self, licensePath):
         if licensePath is None:
             raise Exception("an argument is required")
         elif licensePath.__class__.__name__ == 'str':
-            self.getJavaClass().setLicense(licensePath)
-
-    def init(self):
-        return
+            self.get_java_object().setLicense(licensePath)
 
 
-class ConvertErrorAction(Enum):
+class ConvertErrorAction:
     """!
     This class represents action for conversion errors.
     """
+    __jClass = jpype.JClass("com.aspose.python.pdf.ConvertErrorAction")
 
-    Delete = 0
+    Delete = __jClass.Delete
     """!
     Delete convert errors
     """
 
-    Nothing = 1
+    Nothing = 1 #__jClass.getByValue(1) -  None is reserved word in python - replaced to Nothing
     """!
     Do nothing with convert errors
     """
 
 
-class PdfFormat(StrEnum):
+class PdfFormat:
     """!
-    This class represents an pdf format.
+    This class represents a pdf format.
     """
+    __jClass = jpype.JClass("com.aspose.python.pdf.PdfFormat")
 
-    PDF_A_1A = 'PDF_A_1A'
+    PDF_A_1A = __jClass.PDF_A_1A
     """!
     Pdf/A-1a format
     """
 
-    PDF_A_1B = 'PDF_A_1B'
+    PDF_A_1B = __jClass.PDF_A_1B
     """!
     Pdf/A-1b format
     """
 
-    PDF_A_2A = 'PDF_A_2A'
+    PDF_A_2A = __jClass.PDF_A_2A
     """!
     Pdf/A-2a format
     """
 
-    PDF_A_3A = 'PDF_A_3A'
+    PDF_A_3A = __jClass.PDF_A_3A
     """!
     Pdf/A-3a format
     """
 
-    PDF_A_2B = 'PDF_A_2B'
+    PDF_A_2B = __jClass.PDF_A_2B
     """!
     Pdf/A-2b
     """
 
-    PDF_A_2U = 'PDF_A_2U'
+    PDF_A_2U = __jClass.PDF_A_2U
     """!
     Pdf/A-2u format
     """
 
-    PDF_A_3B = 'PDF_A_3B'
+    PDF_A_3B = __jClass.PDF_A_3B
     """!
     Pdf/A-3b format
     """
 
-    PDF_A_3U = 'PDF_A_3U'
+    PDF_A_3U = __jClass.PDF_A_3U
     """!
     Pdf/A-3u format
     """
 
-    v_1_0 = 'v_1_0'
+    v_1_0 = __jClass.v_1_0
     """!
     Adobe version 1
     """
 
-    v_1_1 = 'v_1_1'
+    v_1_1 = __jClass.v_1_1
     """!
     Adobe version 1.1
     """
 
-    v_1_2 = 'v_1_2'
+    v_1_2 = __jClass.v_1_2
     """!
     Adobe version 1.2
     """
 
-    v_1_3 = 'v_1_3'
+    v_1_3 = __jClass.v_1_3
     """!
     Adobe version 1.3
     """
 
-    v_1_4 = 'v_1_4'
+    v_1_4 = __jClass.v_1_4
     """!
     Adobe version 1.4
     """
 
-    v_1_5 = 'v_1_5'
+    v_1_5 = __jClass.v_1_5
     """!
     Adobe version 1.5
     """
 
-    v_1_6 = 'v_1_6'
+    v_1_6 = __jClass.v_1_6
     """!
     Adobe version 1.6
     """
 
-    v_1_7 = 'v_1_7'
+    v_1_7 = __jClass.v_1_7
     """!
     Adobe version 1.7
     """
 
-    v_2_0 = 'v_2_0'
+    v_2_0 = __jClass.v_2_0
     """!
     Adobe version 2.0
     """
 
-    PDF_UA_1 = 'PDF_UA_1'
+    PDF_UA_1 = __jClass.PDF_UA_1
     """!
     PDF/UA-1 format
     """
 
-    PDF_X_1A_2001 = 'PDF_X_1A_2001'
+    PDF_X_1A_2001 = __jClass.PDF_X_1A_2001
     """!
     PDF/X-1a-2001 format
     """
 
-    PDF_X_1A = 'PDF_X_1A'
+    PDF_X_1A = __jClass.PDF_X_1A
     """!
     PDF/X-1a format
     """
 
-    PDF_X_3 = 'PDF_X_3'
+    PDF_X_3 = __jClass.PDF_X_3
     """!
     PDF/X-3 format
     """
 
-    ZUGFeRD = 'ZUGFeRD'
+    ZUGFeRD = __jClass.ZUGFeRD
     """!
     ZUGFeRD format
     """
 
+    PDF_A_4 = __jClass.PDF_A_4
+    """!
+    PDF/A-4 format format
+    """
 
-class SaveFormat(StrEnum):
+    PDF_A_4E = __jClass.PDF_A_4E
+    """!
+    PDF/A-4e format format
+    """
+
+    PDF_A_4F = __jClass.PDF_A_4F
+    """!
+    PDF/A-4f format format
+    """
+
+
+class SaveFormat:
     """!
     Specifies save format
     """
+    __jClass = jpype.JClass("com.aspose.python.pdf.SaveFormat")
 
-    Pdf = 'Pdf'
+    Pdf = __jClass.Pdf
     """!
     means saving without change of format, i.e. as PDF use it please instead of
     'SaveFormat.None', that is obsolete one
     """
 
-    Doc = 'Doc'
+    Doc = __jClass.Doc
     """!
     means saving in DOC format
     """
 
-    Xps = 'Xps'
+    Xps = __jClass.Xps
     """!
     means saving in XPS format
     """
 
-    Html = 'Html'
+    Html = __jClass.Html
     """!
     means saving in XML format
     """
 
-    Xml = 'Xml'
+    Xml = __jClass.Xml
     """!
     means saving in TEX format i.e. format suitable for Latex text editor
     """
 
-    TeX = 'TeX'
+    TeX = __jClass.TeX
     """!
     means saving in DOCX format
     """
 
-    DocX = 'DocX'
+    DocX = __jClass.DocX
     """!
     means saving in SVG format
     """
 
-    Svg = 'Svg'
+    Svg = __jClass.Svg
     """!
     means saving in SVG format
     """
 
-    MobiXml = 'MobiXml'
+    MobiXml = __jClass.MobiXml
     """!
     means saving in MsExcel format
     """
 
-    Excel = 'Excel'
+    Excel = __jClass.Excel
     """!
     means saving in MsExcel format
     """
 
-    Epub = 'Epub'
+    Epub = __jClass.Epub
     """!
     means saving in EPUB format(special format of e-books)
     """
 
 
-class LoadFormat(StrEnum):
+class LoadFormat:
     """!
     Specifies load format
     """
+    javaClassName = "com.aspose.python.pdf.LoadFormat"
+    __jClass = jpype.JClass(javaClassName)
 
-    CGM = 'CGM'
+    CGM = __jClass.CGM
     """!
     means loading of document in CGM format
     """
 
-    HTML = 'HTML'
+    HTML = __jClass.HTML
     """!
     means loading of document in HTML format
     """
 
-    EPUB = 'EPUB'
+    EPUB = __jClass.EPUB
     """!
     means loading of document in EPUB format(special format of e-books)
     """
 
-    XML = 'XML'
+    XML = __jClass.XML
     """!
     means loading of document in XML format(special XML that represent logical structure of PDF document)
     """
 
-    XSLFO = 'XSLFO'
+    XSLFO = __jClass.XSLFO
     """!
     means loading of document in XSLFO format
     """
 
-    PCL = 'PCL'
+    PCL = __jClass.PCL
     """!
     means loading of document in PCL format
     """
 
-    XPS = 'XPS'
+    XPS = __jClass.XPS
     """!
     means loading of document in XPS format
     """
 
-    TEX = 'TEX'
+    TEX = __jClass.TEX
     """!
     means loading of document in TEX format - format of Latex text editor
     """
 
-    SVG = 'SVG'
+    SVG = __jClass.SVG
     """!
     means loading of document in SVG format - format of Latex text editor
     """
 
-    MHT = 'MHT'
+    MHT = __jClass.MHT
     """!
     means loading of document in MHT format(that is packed HTML format)
     """
 
-    PS = 'PS'
+    PS = __jClass.PS
     """!
     means loading of document in PS format(format of PostScript document) 
     """
 
-    MD = 'MD'
+    MD = __jClass.MD
     """!
     means loading document is in MD format (markdown). 
     """
 
-    TXT = 'TXT'
+    TXT = __jClass.TXT
     """!
     means loading document is in TXT format. 
     """
 
-    PDFXML = 'PDFXML'
+    APS = __jClass.APS
+    """!
+    means loading document in APS format.
+    """
+
+    PDFXML = __jClass.CGM
     """!
     Internal PDF document structure in XML format. 
     """
 
+    OFD = __jClass.OFD
+    """!
+    means loading document in OFD format.
+    """
+
+    DJVU = __jClass.DJVU
+    """!
+    means loading document in Djvu format.
+    """
+
+    CDR = __jClass.CDR
+    """!
+    means loading document in CDR format.
+    """
+
 
 class Document(Assist.BaseJavaClass):
     """!
@@ -303,34 +338,31 @@ class Document(Assist.BaseJavaClass):
 
     javaClassName = "com.aspose.python.pdf.Document"
 
-    def init(self):
-        return
-
-    def __init__(self, parameter1, options=None):
+    def __init__(self, parameter1=None, options=None):
 
         if parameter1 is None:
-            raise Exception("an argument is required")
+            java_class_tmp = jpype.JClass(Document.javaClassName)
+            super().__init__(java_class_tmp())
         elif options is None:
             if parameter1.__class__.__name__ == 'bytes':
-                javaClass = jpype.JClass(Document.javaClassName)
+                java_class_tmp = jpype.JClass(Document.javaClassName)
                 # Convert the Python bytearray to a Java byte array
                 j_byte_array = java.nio.ByteBuffer.wrap(parameter1)
                 # Create a ByteArrayInputStream object from the Java byte array
                 byte_input_stream = java.io.ByteArrayInputStream(j_byte_array.array())
-                super().__init__(javaClass(byte_input_stream))
-                self.init()
+                super().__init__(java_class_tmp(byte_input_stream))
             elif parameter1.__class__.__name__ == 'str':
-                javaClass = jpype.JClass(Document.javaClassName)
-                super().__init__(javaClass(parameter1))
-                self.init()
+                java_class_tmp = jpype.JClass(Document.javaClassName)
+                super().__init__(java_class_tmp(parameter1))
         if parameter1.__class__.__name__ == 'str':
-            javaClass = jpype.JClass(Document.javaClassName)
-            if isinstance(options, LoadFormat):
-                super().__init__(javaClass(parameter1, LoadOptions.getLoadOptions(options)))
+            java_class_tmp = jpype.JClass(Document.javaClassName)
+            if isinstance(options,  jpype.JClass("com.aspose.python.pdf.LoadFormat")):
+                super().__init__(java_class_tmp(parameter1, LoadOptions.getLoadOptions(options)))
             elif isinstance(options, LoadOptions):
-                super().__init__(javaClass(parameter1, options.getJClass()))
+                j_class = options.getJClass
+                super().__init__(java_class_tmp(parameter1, j_class))
         elif parameter1.__class__.__name__ == 'bytes':
-            javaClass = jpype.JClass(Document.javaClassName)
+            java_class_tmp = jpype.JClass(Document.javaClassName)
 
             # Convert the Python bytearray to a Java byte array
             j_byte_array = java.nio.ByteBuffer.wrap(parameter1)
@@ -338,18 +370,17 @@ class Document(Assist.BaseJavaClass):
             # Create a ByteArrayInputStream object from the Java byte array
             byte_input_stream = java.io.ByteArrayInputStream(j_byte_array.array())
 
-            if isinstance(options, LoadFormat):
-                super().__init__(javaClass(byte_input_stream, LoadOptions.getLoadOptions(options)))
+            #if options.getClass().toString() == "class com.aspose.python.pdf.LoadFormat":
+            if isinstance(options,  jpype.JClass("com.aspose.python.pdf.LoadFormat")):
+                super().__init__(java_class_tmp(byte_input_stream, LoadOptions.getLoadOptions(options)))
             elif isinstance(options, LoadOptions):
-                super().__init__(javaClass(byte_input_stream, options))
-
-            self.init()
+                super().__init__(java_class_tmp(byte_input_stream, options))
 
     def close(self):
         """!
         Closes all resources used by this document.
         """
-        self.getJavaClass().close()
+        self.get_java_object().close()
 
     def save(self, fileName, options=None):
         """!
@@ -357,31 +388,31 @@ class Document(Assist.BaseJavaClass):
         """
 
         if fileName is None:
-            self.getJavaClass().save()
+            self.get_java_object().save()
         elif options is None:
-            self.getJavaClass().save(fileName)
+            self.get_java_object().save(fileName)
         elif fileName.__class__.__name__ == 'str':
-            if isinstance(options, SaveFormat):
-                self.getJavaClass().save(fileName, SaveOptions.getSaveOptions(options))
+            if isinstance(options,  jpype.JClass("com.aspose.python.pdf.SaveFormat")):
+                self.get_java_object().save(fileName, SaveOptions.getSaveOptions(options))
             if isinstance(options, SaveOptions):
-                self.getJavaClass().save(fileName, options.getJClass)
+                self.get_java_object().save(fileName, options.getJClass)
 
-    def convert(self, output_log, pdfFormat, convertErrorAction):
+    def convert(self, output_log, pdf_format, convert_error_action):
         """!
         Convert document and save errors into the specified file.
         """
 
-        SaveFormatClass = "com.aspose.python.pdf.SaveFormat"
-        javaClass = jpype.JClass(SaveFormatClass)
-        if pdfFormat is None or convertErrorAction is None:
+        if pdf_format is None or convert_error_action is None:
             raise Exception("an argument is required")
         else:
-            self.getJavaClass().convert(output_log, jpype.JClass("com.aspose.python.pdf.PdfFormat").valueOf(pdfFormat),
-                                        convertErrorAction.value)
+            self.get_java_object().convert(output_log, pdf_format,
+                                           convert_error_action)
 
-    def saveInBytes(self, options=None):
+    def save_in_bytes(self, options=None):
         """!
         Saves the document into byte array with a selected file format.
+        :param options:
+        :return: byte_array
         """
 
         SaveFormatClass = "com.aspose.python.pdf.SaveFormat"
@@ -391,12 +422,12 @@ class Document(Assist.BaseJavaClass):
         byte_output_stream = java.io.ByteArrayOutputStream()
 
         if options is None:
-            self.getJavaClass().save(byte_output_stream);
+            self.get_java_object().save(byte_output_stream);
         else:
             if isinstance(options, SaveFormat):
-                self.getJavaClass().save(byte_output_stream, javaClass.valueOf(options))
+                self.get_java_object().save(byte_output_stream, javaClass.valueOf(options))
             if isinstance(options, SaveOptions):
-                self.getJavaClass().save(byte_output_stream, options.getJClass)
+                self.get_java_object().save(byte_output_stream, options.getJClass)
 
         # Convert the ByteArrayOutputStream to a Java byte array
         j_byte_array = byte_output_stream.toByteArray()
@@ -410,34 +441,120 @@ class Document(Assist.BaseJavaClass):
         # Return the Python bytearray
         return py_byte_array
 
+    def flatten(self):
+        """!
+        Removes all fields (and annotations) from the document and place their values instead.
+        """
+        self.get_java_object().flatten()
+
+    def optimize(self):
+        """!
+        Linearize document in order to - open the first page as quickly as possible; - display next
+        page or follow by link to the next page as quickly as possible; - display the page
+        incrementally as it arrives when data for a page is delivered over a slow channel (display
+        the most useful data first); - permit user interaction, such as following a link, to be
+        performed even before the entire page has been received and displayed. Invoking this method
+        doesn't actually save the document. On the contrary the document only is prepared to have
+        optimized structure, call then Save to get optimized document.
+        """
+        self.get_java_object().optimize()
+
+    def optimize_resources(self):
+        """!
+        Optimize resources in the document: 1. Resources which are not used on the document pages are
+        removed; 2. Equal resources are joined into one object; 3. Unused objects are deleted.
+        """
+        self.get_java_object().optimize_resources()
+
     @property
     def getJClass(self):
         return self.javaClass
 
     @property
-    def getPages(self):
-        return PageCollection(self.getJavaClass().getPages())
+    def pages(self):
+        return PageCollection(self.get_java_object().getPages())
 
 
-class PageCollection(Assist.BaseJavaClass):
+class BaseParagraph(Assist.BaseJavaClass):
     """!
-    Class representing PDF document's page collection
+    Represents an abstract base object can be added to the page
     """
 
-    javaClassName = "com.aspose.python.pdf.PageCollection"
+    javaClassName = "com.aspose.python.pdf.BaseParagraph"
 
-    def init(self):
-        return
+    def __init__(self, java_class):
+        super().__init__(java_class)
 
-    def __init__(self, pageCollection):
-        self.pageCollection = pageCollection
 
-    def getPage(self, pageNumber):
-        return Page(self.pageCollection.get_Item(pageNumber))
+class Paragraphs(Assist.BaseJavaClass):
+    """!
+    This class represents paragraph collection.
+    """
+
+    javaClassName = "com.aspose.python.pdf.Paragraphs"
+
+    def __init__(self, paragraph_collection):
+        super().__init__(paragraph_collection)
+
+    def get_item(self, paragraph_number) -> BaseParagraph:
+        """
+        Gets paragraph from collection.
+        :param paragraph_number: Index of paragraph.
+        :return: Retrieved paragraph.
+        """
+        return BaseParagraph(self.java_object.get_item(paragraph_number))
+
+    def add(self, paragraph: BaseParagraph):
+        """
+        Adds paragraph to collection.
+        :param paragraph: Page to add
+        :return: Added page.
+        """
+        self.java_object.add(paragraph.javaClass)
+
+    def insert(self, index, paragraph: BaseParagraph):
+        """
+        Insert paragraph to collection.
+        :param index: The index for paragraph.
+        :param paragraph: Page to add
+        :return: Added page.
+        """
+        self.javaClass.insert(index, paragraph.java_object)
+
+    def set_item(self, index, paragraph: BaseParagraph):
+        """
+        Sets paragraph to collection.
+        :param index: The index for paragraph.
+        :param paragraph: Page to add
+        :return: Added page.
+        """
+        self.java_object.set_Item(index, paragraph.java_object)
+
+    def remove(self, paragraph: BaseParagraph):
+        """
+        Remove paragraph from collection.
+        :param paragraph: Page to add
+        :return: Added page.
+        """
+        self.java_object.remove(index, paragraph.java_object)
+
+    def remove_range(self, index, count):
+        """
+        Remove paragraph from collection.
+        :param count: The paragraphs count.
+        :param index: The first paragraph index.
+        :return: Added page.
+        """
+        self.java_object.removeRange(index, count)
 
     @property
     def size(self):
-        return self.pageCollection.size()
+        """
+        Get paragraphs count.
+        :param self:
+        :return: paragraphs count.
+        """
+        return self.java_object.getCount()
 
 
 class Page(Assist.BaseJavaClass):
@@ -447,11 +564,68 @@ class Page(Assist.BaseJavaClass):
 
     javaClassName = "com.aspose.python.pdf.Page"
 
-    def init(self):
-        return
+    def __init__(self, java_class):
+        super().__init__(java_class)
 
-    def __init__(self, page):
-        self.page = page
+    @property
+    def paragraphs(self) -> Paragraphs:
+        """!
+        Gets the paragraphs.
+        """
+        return Paragraphs(self.get_java_object().getParagraphs())
+
+
+class PageCollection(Assist.BaseJavaClass):
+    """!
+    Class representing PDF document's page collection
+    """
+
+    javaClassName = "com.aspose.python.pdf.PageCollection"
+
+    def __init__(self, page_collection):
+        super().__init__(page_collection)
+
+    def get_item(self, page_number) -> Page:
+        """
+        Gets page by index.
+        :param page_number: Index of page.
+        :return: Retrieved page.
+        """
+        return Page(self.java_object.get_Item(page_number))
+
+    def add(self, page: Page = None) -> Page:
+        """
+        Adds page to collection.
+        :param page: Page to add
+        :return: Added page.
+        """
+        if page is not None:
+            return Page(self.java_object.add(page))
+        else:
+            return Page(self.java_object.add())
+
+    def insert(self, index, page: Page = None) -> Page:
+        """
+        Insert page into collection at the specified position.
+        :param index: The index for page.
+        :param page: Page to add
+        :return: Added page.
+        """
+        if Page is None:
+            return Page(self.java_object.insert(index))
+        else:
+            return Page(self.java_object.insert(index, page.javaClass))
+
+    def delete(self, index):
+        """
+        Delete specified page.
+        :param index: The index for page.
+        """
+        self.java_object.delete(index)
+
+    @property
+    def size(self):
+        return self.java_object.size()
 
 
 class LoadOptions:
@@ -507,83 +681,112 @@ class LoadOptions:
             Options = jpype.JClass('com.aspose.python.pdf.TeXLoadOptions')
             return Options()
 
+
     @property
     def getLoadFormat(self):
         return self.__loadFormat
 
     @property
     def getJClass(self):
-        return self.__jClass
+        return self._jClass
 
 
 class EpubLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.EPUB
-    __jClass = jpype.JClass("com.aspose.python.pdf.EpubLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.EpubLoadOptions")()
 
 
 class HtmlLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.HTML
-    __jClass = jpype.JClass("com.aspose.python.pdf.HtmlLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.HtmlLoadOptions")()
 
 
 class MdLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.MD
-    __jClass = jpype.JClass("com.aspose.python.pdf.MdLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.MdLoadOptions")()
 
 
 class MhtLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.MHT
-    __jClass = jpype.JClass("com.aspose.python.pdf.MhtLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.MhtLoadOptions")()
 
 
 class PclLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.PCL
-    __jClass = jpype.JClass("com.aspose.python.pdf.PclLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.PclLoadOptions")()
 
 
 class PdfXmlLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.PDFXML
-    __jClass = jpype.JClass("com.aspose.python.pdf.PdfXmlLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.PdfXmlLoadOptions")()
 
 
 class PsLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.PS
-    __jClass = jpype.JClass("com.aspose.python.pdf.PsLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.PsLoadOptions")()
 
 
 class SvgLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.SVG
-    __jClass = jpype.JClass("com.aspose.python.pdf.SvgLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.SvgLoadOptions")()
 
 
 class TeXLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.TEX
-    __jClass = jpype.JClass("com.aspose.python.pdf.TeXLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.TeXLoadOptions")()
 
 
 class TxtLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.TXT
-    __jClass = jpype.JClass("com.aspose.python.pdf.TxtLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.TxtLoadOptions")()
 
 
 class XmlLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.XML
-    __jClass = jpype.JClass("com.aspose.python.pdf.XmlLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.XmlLoadOptions")()
 
 
 class XpsLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.XPS
-    __jClass = jpype.JClass("com.aspose.python.pdf.XpsLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.XpsLoadOptions")()
 
 
 class XslFoLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.XSLFO
-    __jClass = jpype.JClass("com.aspose.python.pdf.XslFoLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.XslFoLoadOptions")()
 
 
 class CgmLoadOptions(LoadOptions):
     __loadFormat = LoadFormat.CGM
-    __jClass = jpype.JClass("com.aspose.python.pdf.CgmLoadOptions")
+
+    def __init__(self):
+        self._jClass = jpype.JClass("com.aspose.python.pdf.CgmLoadOptions")()
 
 
 class SaveOptions:
@@ -652,40 +855,42 @@ class SaveOptions:
 
 
 class DocSaveOptions(SaveOptions):
-    class DocFormat(StrEnum):
+    class DocFormat:
         """!
         Allows to specify .doc or .docx file format.
         """
+        __jClass = jpype.JClass("com.aspose.python.pdf.DocSaveOptions.DocFormat")
 
-        Doc = 'Doc'
+        Doc = __jClass.Doc
         """!
         [MS-DOC]: Word (.doc) Binary File Format
         """
 
-        Docx = 'Docx'
+        Docx = __jClass.DocX
         """!
         Office Open XML (.docx) File Format
         """
 
-    class RecognitionMode(StrEnum):
+    class RecognitionMode:
         """!
         Allows to control how a PDF document is converted into a word processing document.
         """
+        __jClass = jpype.JClass("com.aspose.python.pdf.DocSaveOptions.RecognitionMode")
 
-        Textbox = 'Textbox'
+        Textbox = __jClass.Textbox
         """!
         This mode is fast and good for maximally preserving original look of the PDF file, but
         editability of the resulting document could be limited.
         """
 
-        Flow = 'Flow'
+        Flow = __jClass.Flow
         """!
         Full recognition mode, the engine performs grouping and multi-level analysis to restore
         the original document author's intent and produce a maximally editable document. The
         downside is that the output document might look different from the original PDF file.
         """
 
-        EnhancedFlow = 'EnhancedFlow'
+        EnhancedFlow = __jClass.EnhancedFlow
         """!
         An early alfa version of a new Flow mode supporting recognition of tables.
         """
@@ -699,17 +904,8 @@ class DocSaveOptions(SaveOptions):
     @property
     def getJClass(self):
 
-        if self.format == self.DocFormat.Doc:
-            self.__jClass.setFormat(0)
-        else:
-            self.__jClass.setFormat(1)
-
-        if self.mode == self.RecognitionMode.Textbox:
-            self.__jClass.setMode(0)
-        elif self.mode == self.RecognitionMode.Flow:
-            self.__jClass.setMode(1)
-        else:
-            self.__jClass.setMode(2)
+        self.__jClass.setFormat(self.format)
+        self.__jClass.setMode(self.mode)
 
         self.__jClass.setRelativeHorizontalProximity(self.relative_horizontal_proximity)
         self.__jClass.setRecognizeBullets(self.recognize_bullets)
@@ -717,34 +913,41 @@ class DocSaveOptions(SaveOptions):
 
 
 class ExcelSaveOptions(SaveOptions):
-    class ExcelFormat(StrEnum):
+    class ExcelFormat:
         """!
         Allows to specify .xls/xml or .xlsx file format. Default value is XLSX;
         """
 
-        XMLSpreadSheet2003 = 'XMLSpreadSheet2003'
+        javaClassName = "com.aspose.python.pdf.ExcelSaveOptions.ExcelFormat"
+        __jClass = jpype.JClass(javaClassName)
+        XMLSpreadSheet2003 = __jClass.XMLSpreadSheet2003
         """!
-        Excel 2003 XML Format
+         Excel 2003 XML Format
+
         """
 
-        XLSX = 'XLSX'
+        XLSX = __jClass.XLSX
         """!
-        Office Open XML (.xlsx) File Format
+         Office Open XML (.xlsx) File Format
+
         """
 
-        CSV = 'CSV'
+        CSV = __jClass.CSV
         """!
-        A comma-separated values (CSV) File Format
+         A comma-separated values (CSV) File Format
+
         """
 
-        XLSM = 'XLSM'
+        XLSM = __jClass.XLSM
         """!
-        A macro-enabled Office Open XML (.xlsm) File Format
+         A macro-enabled Office Open XML (.xlsm) File Format
+
         """
 
-        ODS = 'ODS'
+        ODS = __jClass.ODS
         """!
-        OpenDocument Spreadsheet
+         OpenDocument Spreadsheet
+
         """
 
     __jClass = jpype.JClass("com.aspose.python.pdf.ExcelSaveOptions")()
@@ -755,17 +958,7 @@ class ExcelSaveOptions(SaveOptions):
 
     @property
     def getJClass(self):
-        if self._format == self.ExcelFormat.XMLSpreadSheet2003:
-            self.__jClass.setFormat(0)
-        elif self._format == self.ExcelFormat.XLSX:
-            self.__jClass.setFormat(1)
-        elif self._format == self.ExcelFormat.CSV:
-            self.__jClass.setFormat(2)
-        elif self._format == self.ExcelFormat.XLSM:
-            self.__jClass.setFormat(3)
-        elif self._format == self.ExcelFormat.ODS:
-            self.__jClass.setFormat(4)
-
+        self.__jClass.setFormat(self._format)
         self.__jClass.setInsertBlankColumnAtFirst(self._insertBlankColumnAtFirst)
         self.__jClass.setMinimizeTheNumberOfWorksheets(self._minimizeTheNumberOfWorksheets)
         self.__jClass.setUniformWorksheets(self._uniformWorksheets)
@@ -831,7 +1024,6 @@ class HtmlSaveOptions(SaveOptions):
 
 
 class PptxSaveOptions(SaveOptions):
-
     __jClass = jpype.JClass("com.aspose.python.pdf.PptxSaveOptions")()
     _ImageResolution = 192
     _SlidesAsImages = False
@@ -840,7 +1032,6 @@ class PptxSaveOptions(SaveOptions):
 
     @property
     def getJClass(self):
-
         self.__jClass.setSlidesAsImages(self._SlidesAsImages)
         self.__jClass.setSeparateImages(self._SeparateImages)
         self.__jClass.setOptimizeTextBoxes(self._OptimizeTextBoxes)
@@ -848,8 +1039,178 @@ class PptxSaveOptions(SaveOptions):
 
 
 class PdfFileEditor(SaveOptions):
-
     __jClass = jpype.JClass("com.aspose.python.pdf.facades.PdfFileEditor")()
 
     def concatenate(self, firstInputFile, secInputFile, outputFile):
         self.__jClass.concatenate(firstInputFile, secInputFile, outputFile)
+
+
+class TextFragment(Assist.BaseJavaClass):
+    """!
+    Represents fragment of Pdf text.
+    """
+
+    javaClassName = "com.aspose.python.pdf.TextFragment"
+
+    def __init__(self, text=None, java_class=None):
+        if java_class is None:
+            self.text = text
+            java_class_link = jpype.JClass(self.javaClassName)
+            if text is None:
+                self.javaClass = java_class_link()
+            else:
+                self.javaClass = java_class_link(self.text)
+        else:
+            super().__init__(java_class)
+
+    @property
+    def getPage(self) -> Page:
+        """!
+        Gets page that contains the TextFragment
+        The value can be null in case the TextFragment object doesn't belong to any page.
+        """
+        return Page(self.get_java_object().page())
+
+    def getText(self) -> str:
+        """!
+        Gets string text object that the TextFragment object represents.
+        :return: text
+        """
+        return str(self.get_java_object().getText())
+
+    def setText(self, replace_text):
+        """!
+        Sets {@code string} text object that the {@code TextFragment} object represents.
+        :param replace_text: String value
+        """
+        return str(self.get_java_object().setText(replace_text))
+
+    @property
+    def getRectangle(self):
+        """!
+        Gets rectangle of the TextFragment
+        :return: Gets rectangle of the TextFragment
+        """
+        return Rectangle(self.get_java_object().get_rectangle())
+
+
+class TextFragmentCollection(Assist.BaseJavaClass):
+    """!
+    Represents a text fragments collection
+    """
+
+    javaClassName = "com.aspose.python.pdf.TextFragmentCollection"
+
+    def __init__(self, java_class):
+        super().__init__(java_class)
+
+    def clear(self):
+        """!
+        Clears all items from the collection.
+        """
+        self.get_java_object().clear()
+
+    def get_item(self, index: int) -> TextFragment:
+        """!
+        Gets the text fragment element at the specified index.
+        :return: TextFragment
+        :param index:
+        """
+        return TextFragment(java_class=self.get_java_object().get_Item(index))
+
+    @property
+    def size(self):
+        """!
+        Gets the number of {@code TextFragment} object elements actually contained in the collection.
+        :return: TextFragment elements count
+        """
+        return self.get_java_object().size()
+
+
+class Rectangle(Assist.BaseJavaClass):
+    """!
+    Class represents rectangle.
+    """
+
+    javaClassName = "com.aspose.python.pdf.Rectangle"
+
+    def __init__(self, llx=None, lly=None, urx=None, ury=None, java_class=None):
+        """!
+        Rectangle constructor.
+       @param llx X of lower left corner.
+       @param lly Y of lower left corner.
+       @param urx of upper right corner.
+       @param ury of upper right corner.
+        """
+        if java_class is None:
+            java_class = jpype.JClass(self.javaClassName)
+            self.javaClass = java_class(llx, lly, urx, ury)
+            super().__init__(self.javaClass)
+        else:
+            super().__init__(java_class)
+
+    def getLLX(self):
+        """!
+        Gets X-coordinate of lower - left corner.
+        @return Gets X-coordinate of lower - left corner.
+        """
+        return int(self.get_java_object().getLLX())
+
+    def getLLY(self):
+        """!
+       Gets Y - coordinate of lower-left corner.
+        @return Gets Y - coordinate of lower-left corner.
+        """
+        return int(self.get_java_object().getLLY())
+
+    def getURX(self):
+        """!
+        Gets X - coordinate of upper-right corner.
+        @returns Gets X - coordinate of upper-right corner.
+        """
+        return self.getURX()
+
+    def getURY(self):
+        """!
+        Gets Y - coordinate of upper-right corner.
+        @returns Gets Y - coordinate of upper-right corner.
+        """
+        return self.getURY()
+
+    def getWidth(self):
+        """!
+        Returns the width of the bounding Rectangle in
+        double precision.
+        @return the width of the bounding Rectangle.
+        """
+        return int(self.get_java_object().getWidth())
+
+    def getHeight(self):
+        """!
+        Returns the height of the bounding Rectangle in
+        double precision.
+        @return the height of the bounding Rectangle.
+        """
+        return int(self.get_java_object().getHeight())
+
+    def toString(self):
+        return str(self.get_java_object().toString())
+
+    def equals(self, obj):
+        return self.get_java_object().equals(obj.get_java_object())
+
+    def intersect(self, rectangle: 'Rectangle'):
+        """!
+       Intersects to rectangles.
+       @param rectangle
+       @returns {boolean
+        """
+        return self.get_java_object().intersect(rectangle.javaClass)
+
+    @property
+    def isEmpty(self) -> bool:
+        """
+        Checks if rectangle is empty.
+        :return:
+        """
+        return self.get_java_object().isEmpty
